aboutsummaryrefslogtreecommitdiff
path: root/pkgs/top-level
diff options
context:
space:
mode:
authorEelco Dolstra <eelco.dolstra@logicblox.com>2012-12-28 19:08:19 +0100
committerEelco Dolstra <eelco.dolstra@logicblox.com>2012-12-28 19:08:19 +0100
commit5be0a9acd7b9abe4bff3202a7ac7defc17a37877 (patch)
tree25491a83f604f1ace6a1170505955df5817495c2 /pkgs/top-level
parentf4ed8a3b911628335a53b3b5ddb48e9ec8d8bdcf (diff)
Rename hostDrv -> crossDrv, buildDrv -> nativeDrv
This is for consistency with terminology in stdenv (and the terms "hostDrv" and "buildDrv" are not very intuitive, even if they're consistent with GNU terminology).
Diffstat (limited to 'pkgs/top-level')
-rw-r--r--pkgs/top-level/all-packages.nix16
-rw-r--r--pkgs/top-level/release-cross.nix156
-rw-r--r--pkgs/top-level/release-lib.nix2
3 files changed, 87 insertions, 87 deletions
diff --git a/pkgs/top-level/release-cross.nix b/pkgs/top-level/release-cross.nix
index 63fffd7d3161..e8be588b7564 100644
--- a/pkgs/top-level/release-cross.nix
+++ b/pkgs/top-level/release-cross.nix
@@ -5,21 +5,21 @@ let
/* Basic list of packages to cross-build */
basicHostDrv = {
gccCrossStageFinal = nativePlatforms;
- bison.hostDrv = nativePlatforms;
- busybox.hostDrv = nativePlatforms;
- coreutils.hostDrv = nativePlatforms;
- dropbear.hostDrv = nativePlatforms;
- tigervnc.hostDrv = nativePlatforms;
- #openoffice.hostDrv = nativePlatforms;
- wxGTK.hostDrv = nativePlatforms;
+ bison.crossDrv = nativePlatforms;
+ busybox.crossDrv = nativePlatforms;
+ coreutils.crossDrv = nativePlatforms;
+ dropbear.crossDrv = nativePlatforms;
+ tigervnc.crossDrv = nativePlatforms;
+ #openoffice.crossDrv = nativePlatforms;
+ wxGTK.crossDrv = nativePlatforms;
#firefox = nativePlatforms;
xorg = {
- #xorgserver.hostDrv = nativePlatforms;
+ #xorgserver.crossDrv = nativePlatforms;
};
- nixUnstable.hostDrv = nativePlatforms;
- linuxPackages_3_3.kernel.hostDrv = linux;
- linuxPackages_3_4.kernel.hostDrv = linux;
- linuxPackages_3_6.kernel.hostDrv = linux;
+ nixUnstable.crossDrv = nativePlatforms;
+ linuxPackages_3_3.kernel.crossDrv = linux;
+ linuxPackages_3_4.kernel.crossDrv = linux;
+ linuxPackages_3_6.kernel.crossDrv = linux;
};
/* Basic list of packages to be natively built,
@@ -50,7 +50,7 @@ in {
crossSheevaplugLinux = mapTestOnCross crossSystem (
basic //
{
- ubootSheevaplug.hostDrv = nativePlatforms;
+ ubootSheevaplug.crossDrv = nativePlatforms;
});
}) // (
@@ -79,7 +79,7 @@ in {
crossSheevaplugLinuxUclibc = mapTestOnCross crossSystem (
basic //
{
- ubootSheevaplug.hostDrv = nativePlatforms;
+ ubootSheevaplug.crossDrv = nativePlatforms;
});
}) // (
@@ -153,14 +153,14 @@ let
};
in {
crossMingw32 = mapTestOnCross crossSystem {
- coreutils.hostDrv = nativePlatforms;
- boehmgc.hostDrv = nativePlatforms;
- gmp.hostDrv = nativePlatforms;
- guile_1_8.hostDrv = nativePlatforms;
- libffi.hostDrv = nativePlatforms;
- libtool.hostDrv = nativePlatforms;
- libunistring.hostDrv = nativePlatforms;
- windows.wxMSW.hostDrv = nativePlatforms;
+ coreutils.crossDrv = nativePlatforms;
+ boehmgc.crossDrv = nativePlatforms;
+ gmp.crossDrv = nativePlatforms;
+ guile_1_8.crossDrv = nativePlatforms;
+ libffi.crossDrv = nativePlatforms;
+ libtool.crossDrv = nativePlatforms;
+ libunistring.crossDrv = nativePlatforms;
+ windows.wxMSW.crossDrv = nativePlatforms;
};
}) // (
@@ -176,14 +176,14 @@ let
};
in {
crossMingwW64 = mapTestOnCross crossSystem {
- coreutils.hostDrv = nativePlatforms;
- boehmgc.hostDrv = nativePlatforms;
- gmp.hostDrv = nativePlatforms;
- guile_1_8.hostDrv = nativePlatforms;
- libffi.hostDrv = nativePlatforms;
- libtool.hostDrv = nativePlatforms;
- libunistring.hostDrv = nativePlatforms;
- windows.wxMSW.hostDrv = nativePlatforms;
+ coreutils.crossDrv = nativePlatforms;
+ boehmgc.crossDrv = nativePlatforms;
+ gmp.crossDrv = nativePlatforms;
+ guile_1_8.crossDrv = nativePlatforms;
+ libffi.crossDrv = nativePlatforms;
+ libtool.crossDrv = nativePlatforms;
+ libunistring.crossDrv = nativePlatforms;
+ windows.wxMSW.crossDrv = nativePlatforms;
};
}) // (
@@ -202,34 +202,34 @@ let
in {
crossGNU = mapTestOnCross crossSystem {
gnu.hurdCross = nativePlatforms;
- gnu.mach.hostDrv = nativePlatforms;
+ gnu.mach.crossDrv = nativePlatforms;
gnu.mig = nativePlatforms;
- gnu.smbfs.hostDrv = nativePlatforms;
+ gnu.smbfs.crossDrv = nativePlatforms;
- coreutils.hostDrv = nativePlatforms;
- ed.hostDrv = nativePlatforms;
- grub2.hostDrv = nativePlatforms;
- inetutils.hostDrv = nativePlatforms;
- boehmgc.hostDrv = nativePlatforms;
- findutils.hostDrv = nativePlatforms;
- gcc.hostDrv = nativePlatforms;
- gcc46.hostDrv = nativePlatforms;
- gdb.hostDrv = nativePlatforms;
- gmp.hostDrv = nativePlatforms;
- gnugrep.hostDrv = nativePlatforms;
- gnumake.hostDrv = nativePlatforms;
- gnused.hostDrv = nativePlatforms;
- guile_1_8.hostDrv = nativePlatforms;
- guile.hostDrv = nativePlatforms;
- libffi.hostDrv = nativePlatforms;
- libtool.hostDrv = nativePlatforms;
- libunistring.hostDrv = nativePlatforms;
- lsh.hostDrv = nativePlatforms;
- nixUnstable.hostDrv = nativePlatforms;
- openssl.hostDrv = nativePlatforms; # dependency of Nix
- patch.hostDrv = nativePlatforms;
- samba_light.hostDrv = nativePlatforms; # needed for `runInGenericVM'
- zile.hostDrv = nativePlatforms;
+ coreutils.crossDrv = nativePlatforms;
+ ed.crossDrv = nativePlatforms;
+ grub2.crossDrv = nativePlatforms;
+ inetutils.crossDrv = nativePlatforms;
+ boehmgc.crossDrv = nativePlatforms;
+ findutils.crossDrv = nativePlatforms;
+ gcc.crossDrv = nativePlatforms;
+ gcc46.crossDrv = nativePlatforms;
+ gdb.crossDrv = nativePlatforms;
+ gmp.crossDrv = nativePlatforms;
+ gnugrep.crossDrv = nativePlatforms;
+ gnumake.crossDrv = nativePlatforms;
+ gnused.crossDrv = nativePlatforms;
+ guile_1_8.crossDrv = nativePlatforms;
+ guile.crossDrv = nativePlatforms;
+ libffi.crossDrv = nativePlatforms;
+ libtool.crossDrv = nativePlatforms;
+ libunistring.crossDrv = nativePlatforms;
+ lsh.crossDrv = nativePlatforms;
+ nixUnstable.crossDrv = nativePlatforms;
+ openssl.crossDrv = nativePlatforms; # dependency of Nix
+ patch.crossDrv = nativePlatforms;
+ samba_light.crossDrv = nativePlatforms; # needed for `runInGenericVM'
+ zile.crossDrv = nativePlatforms;
};
}) // (
@@ -261,13 +261,13 @@ let
in {
fuloongminipc = mapTestOnCross crossSystem {
- coreutils.hostDrv = nativePlatforms;
- ed.hostDrv = nativePlatforms;
- grub2.hostDrv = nativePlatforms;
- inetutils.hostDrv = nativePlatforms;
- nixUnstable.hostDrv = nativePlatforms;
- patch.hostDrv = nativePlatforms;
- zile.hostDrv = nativePlatforms;
+ coreutils.crossDrv = nativePlatforms;
+ ed.crossDrv = nativePlatforms;
+ grub2.crossDrv = nativePlatforms;
+ inetutils.crossDrv = nativePlatforms;
+ nixUnstable.crossDrv = nativePlatforms;
+ patch.crossDrv = nativePlatforms;
+ zile.crossDrv = nativePlatforms;
};
}) // (
@@ -321,20 +321,20 @@ let
in {
nanonote = mapTestOnCross crossSystem {
- coreutils.hostDrv = nativePlatforms;
- ed.hostDrv = nativePlatforms;
- inetutils.hostDrv = nativePlatforms;
- nixUnstable.hostDrv = nativePlatforms;
- patch.hostDrv = nativePlatforms;
- zile.hostDrv = nativePlatforms;
- prboom.hostDrv = nativePlatforms;
- vim.hostDrv = nativePlatforms;
- lynx.hostDrv = nativePlatforms;
- patchelf.hostDrv = nativePlatforms;
- nix.hostDrv = nativePlatforms;
- fossil.hostDrv = nativePlatforms;
- binutils.hostDrv = nativePlatforms;
- mpg123.hostDrv = nativePlatforms;
- yacas.hostDrv = nativePlatforms;
+ coreutils.crossDrv = nativePlatforms;
+ ed.crossDrv = nativePlatforms;
+ inetutils.crossDrv = nativePlatforms;
+ nixUnstable.crossDrv = nativePlatforms;
+ patch.crossDrv = nativePlatforms;
+ zile.crossDrv = nativePlatforms;
+ prboom.crossDrv = nativePlatforms;
+ vim.crossDrv = nativePlatforms;
+ lynx.crossDrv = nativePlatforms;
+ patchelf.crossDrv = nativePlatforms;
+ nix.crossDrv = nativePlatforms;
+ fossil.crossDrv = nativePlatforms;
+ binutils.crossDrv = nativePlatforms;
+ mpg123.crossDrv = nativePlatforms;
+ yacas.crossDrv = nativePlatforms;
};
})
diff --git a/pkgs/top-level/release-lib.nix b/pkgs/top-level/release-lib.nix
index 4a5f7602d02d..3509cf7f31f0 100644
--- a/pkgs/top-level/release-lib.nix
+++ b/pkgs/top-level/release-lib.nix
@@ -65,7 +65,7 @@ rec {
/* Similar to the testOn function, but with an additional 'crossSystem'
* parameter for allPackages, defining the target platform for cross builds,
- * and triggering the build of the host derivation (cross built - hostDrv). */
+ * and triggering the build of the host derivation (cross built - crossDrv). */
mapTestOnCross = crossSystem: pkgs.lib.mapAttrsRecursiveCond
(as: !(as ? type && as.type == "job"))
(path: value:
diff --git a/pkgs/top-level/all-packages.nix b/pkgs/top-level/all-packages.nix
index e4001c63258c..8233b59e0b2d 100644
--- a/pkgs/top-level/all-packages.nix
+++ b/pkgs/top-level/all-packages.nix
@@ -223,7 +223,7 @@ let
defaultStdenv;
forceBuildDrv = drv : if (crossSystem == null) then drv else
- (drv // { hostDrv = drv.buildDrv; });
+ (drv // { crossDrv = drv.nativeDrv; });
# A stdenv capable of building 32-bit binaries. On x86_64-linux,
# it uses GCC compiled with multilib support; on i686-linux, it's
@@ -1276,7 +1276,7 @@ let
gettext = null;
readline = null;
devicemapper = null;
- }).hostDrv)
+ }).crossDrv)
{ hurd = gnu.hurdCrossIntermediate; })
else null;
@@ -2045,7 +2045,7 @@ let
# http://gcc.gnu.org/bugzilla/show_bug.cgi?id=43944
profiledCompiler = if stdenv.isArm then false else true;
# When building `gcc.hostDrv' (a "Canadian cross", with host == target
# and host != build), `cross' must be null but the cross-libc must still
# be passed.
cross = null;
@@ -2074,7 +2074,7 @@ let
# http://gcc.gnu.org/bugzilla/show_bug.cgi?id=43944
profiledCompiler = if stdenv.isArm then false else true;
# When building `gcc.hostDrv' (a "Canadian cross", with host == target
# and host != build), `cross' must be null but the cross-libc must still
# be passed.
cross = null;
@@ -2101,7 +2101,7 @@ let
# We can enable it back some day. This makes the *gcc* builds faster now.
profiledCompiler = false;
# When building `gcc.hostDrv' (a "Canadian cross", with host == target
# and host != build), `cross' must be null but the cross-libc must still
# be passed.
cross = null;
@@ -3176,7 +3176,7 @@ let
pmccabe = callPackage ../development/tools/misc/pmccabe { };
/* Make pkgconfig always return a buildDrv, never a proper hostDrv,
because most usage of pkgconfig as buildInput (inheritance of
pre-cross nixpkgs) means using it using as buildNativeInput
cross_renaming: we should make all programs use pkgconfig as
@@ -3634,7 +3634,7 @@ let
machHeaders = null;
hurdHeaders = null;
gccCross = null;
- }) // (if crossSystem != null then { hostDrv = glibc213Cross; } else {});
+ }) // (if crossSystem != null then { crossDrv = glibc213Cross; } else {});
glibc213Cross = forceBuildDrv (makeOverridable (import ../development/libraries/glibc/2.13)
(let crossGNU = crossSystem != null && crossSystem.config == "i586-pc-gnu";
@@ -5583,7 +5583,7 @@ let
libuuid =
if crossSystem != null && crossSystem.config == "i586-pc-gnu"
then (utillinux // {
- hostDrv = lib.overrideDerivation utillinux.hostDrv (args: {
+ crossDrv = lib.overrideDerivation utillinux.crossDrv (args: {
# `libblkid' fails to build on GNU/Hurd.
configureFlags = args.configureFlags
+ " --disable-libblkid --disable-mount --disable-libmount"
@@ -2045,7 +2045,7 @@ let
# http://gcc.gnu.org/bugzilla/show_bug.cgi?id=43944
profiledCompiler = if stdenv.isArm then false else true;
- # When building `gcc.hostDrv' (a "Canadian cross", with host == target
+ # When building `gcc.crossDrv' (a "Canadian cross", with host == target
# and host != build), `cross' must be null but the cross-libc must still
# be passed.
@@ -2074,7 +2074,7 @@ let
# http://gcc.gnu.org/bugzilla/show_bug.cgi?id=43944
profiledCompiler = if stdenv.isArm then false else true;
- # When building `gcc.hostDrv' (a "Canadian cross", with host == target
+ # When building `gcc.crossDrv' (a "Canadian cross", with host == target
# and host != build), `cross' must be null but the cross-libc must still
# be passed.
@@ -2101,7 +2101,7 @@ let
# We can enable it back some day. This makes the *gcc* builds faster now.
profiledCompiler = false;
- # When building `gcc.hostDrv' (a "Canadian cross", with host == target
+ # When building `gcc.crossDrv' (a "Canadian cross", with host == target
# and host != build), `cross' must be null but the cross-libc must still
# be passed.
@@ -3176,7 +3176,7 @@ let
pmccabe = callPackage ../development/tools/misc/pmccabe { };
- /* Make pkgconfig always return a buildDrv, never a proper hostDrv,
+ /* Make pkgconfig always return a nativeDrv, never a proper crossDrv,
because most usage of pkgconfig as buildInput (inheritance of
pre-cross nixpkgs) means using it using as buildNativeInput